%define use_nss 1
%define ldap_support 1
%define static_ldap 1
%define krb5_support 1
%define nntp_support 1

%define glib2_version 2.26.1
%define gtk2_version 2.22.1
%define gtk_doc_version 1.14
%define intltool_version 0.35.5
%define orbit2_version 2.14.19
%define soup_version 2.32.0
%define libgweather_version 2.30.3
%define libical_version 0.44
%define libgdata_version 0.6.5

%define eds_base_version 2.32
%define eds_api_version 1.2

%define use_gnome_keyring 1
%define support_imap4_provider 0

%define camel_provider_dir %{_libdir}/evolution-data-server-%{eds_api_version}/camel-providers
%define eds_extensions_dir %{_libdir}/evolution-data-server-%{eds_api_version}/extensions

# Use stricter build settings than required by upstream.
%define strict_build_settings 1

### Abstract ###

Summary: Backend data server for evolution
Summary(ja): Evolution バックエンドデータサーバ
Name: evolution-data-server
Version: 2.32.1
Release: 1%{?_dist_release}
License: LGPL
Group: System Environment/Libraries
URL: http://www.gnome.org/projects/evolution/
Source0: http://ftp.gnome.org/pub/GNOME/sources/evolution-data-server/2.32/%{name}-%{version}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{version}-root

### Patches ###

# RH bug #215702 / GNOME bug #487988
Patch10: evolution-data-server-1.8.0-fix-ldap-query.patch

# GNOME bug #373146
Patch11: evolution-data-server-1.10.1-camel-folder-summary-crash.patch

# RH bug #243296
Patch12: evolution-data-server-1.11.5-fix-64bit-acinclude.patch

### Dependencies ###

Requires: GConf2
Requires: ORBit2 >= %{orbit2_version}
Requires: libsoup >= %{soup_version}

### Build Dependencies ###

BuildRequires: GConf2-devel
BuildRequires: ORBit2-devel >= %{orbit2_version}
BuildRequires: bison
BuildRequires: db4-devel
BuildRequires: flex
BuildRequires: gettext
BuildRequires: glib2-devel
BuildRequires: gnutls-devel
BuildRequires: intltool >= %{intltool_version}
BuildRequires: libsoup-devel >= %{soup_version}
BuildRequires: libtool
BuildRequires: libgnome-keyring-devel
BuildRequires: gtk-doc >= 1.14
BuildRequires: sqlite3-devel
BuildRequires: libgweather-devel >= %{libgweather_version}
BuildRequires: libical-devel >= %{libical_version}
BuildRequires: gperf
BuildRequires: krb5-devel
BuildRequires: libgdata-devel >= %{libgdata_version}

%if %{use_nss}
BuildRequires: nspr-devel
BuildRequires: nss-devel
%else
BuildRequires: openssl-devel
%endif

%if %{ldap_support}
%if %{static_ldap}
BuildRequires: openldap-evolution-devel
BuildRequires: openssl-devel
%else
BuildRequires: openldap-devel >= 2.0.11 
%endif
%endif

%if %{krb5_support} 
BuildRequires: krb5-devel 
# tweak for krb5 1.2 vs 1.3
%define krb5dir /usr/kerberos
#define krb5dir `pwd`/krb5-fakeprefix
%endif

%description
The evolution-data-server package provides a unified backend for 
programs that work with contacts, tasks, and calendar information.

It was originally developed for Evolution (hence the name), but 
is now used by other packages.

%package devel
Summary: Development files for building against evolution-data-server
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: libgnome-devel
Requires: libgweather-devel
Requires: libsoup-devel
Requires: libical-devel >= %{libical_version}
Requires: sqlite3-devel
%if %{use_nss}
Requires: nspr-devel
Requires: nss-devel
%endif

%description devel
Development files needed for building things which link against 
evolution-data-server.

%package doc
Summary: Documentation files for %{name}
Group: Applications/Documentation

%description doc
This package contains developer documentation for %{name}.

%prep
%setup -q

## %patch10 -p1 -b .fix-ldap-query
##%patch11 -p1 -b .camel-folder-summary-crash
%patch12 -p1 -b .fix-64bit-acinclude

mkdir -p krb5-fakeprefix/include
mkdir -p krb5-fakeprefix/lib
mkdir -p krb5-fakeprefix/%{_lib}

%build
%if %{ldap_support}

%if %{static_ldap}
%define ldap_flags --with-openldap=%{_libdir}/evolution-openldap --with-static-ldap
# Set LIBS so that configure will be able to link with static LDAP libraries,
# which depend on Cyrus SASL and OpenSSL.  XXX Is the "else" clause necessary?
if pkg-config libssl ; then
	export LIBS="-lsasl2 `pkg-config --libs libssl`"
else
	export LIBS="-lsasl2 -lssl -lcrypto"
fi
%else
%define ldap_flags --with-openldap=yes
%endif

%else
%define ldap_flags --without-openldap
%endif

%if %{krb5_support}
%define krb5_flags --with-krb5=%{krb5dir} --with-krb5-libs=%{_libdir} --with-krb5-includes=%{_includedir}
%else
%define krb5_flags --without-krb5
%endif

%if %{nntp_support}
%define nntp_flags --enable-nntp=yes
%else
%define nntp_flags --enable-nntp=no
%endif

%if %{use_nss}
%define ssl_flags --enable-nss=yes --enable-smime=yes
%else
%define ssl_flags --enable-openssl=yes
%endif

%if %{use_nss}
if ! pkg-config --exists nss; then 
  echo "Unable to find suitable version of nss to use!"
  exit 1
fi
%endif

%if %{use_gnome_keyring}
%define keyring_flags --enable-gnome-keyring
%else
%define keyring flags --disable-gnome-keyring
%endif

%if %{support_imap4_provider}
%define imap4_flags --enable-imap4=yes
%else
%define imap4_flags --enable-imap4=no
%endif

export CPPFLAGS="-I%{_includedir}/et"
export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED -fPIC -I%{_includedir}/et"
%if ! %{use_nss}
if pkg-config openssl ; then
	CFLAGS="$CFLAGS `pkg-config --cflags openssl`"
	LDFLAGS="$LDFLAGS `pkg-config --libs-only-L openssl`"
fi
%endif

# Add stricter build settings here as the source code gets cleaned up.
# We want to make sure things like compiler warnings and avoiding deprecated
# functions in the GNOME/GTK+ libraries stay fixed.
#
# Please file a bug report at bugzilla.gnome.org if these settings break
# compilation, and encourage the upstream developers to use them.

%if %{strict_build_settings}
CFLAGS="$CFLAGS \
	-DG_DISABLE_DEPRECATED=1 \
        -DPANGO_DISABLE_DEPRECATED=1 \
	-DGDK_PIXBUF_DISABLE_DEPRECATED=1 \
	-DGDK_DISABLE_DEPRECATED=1 \
	-Wdeclaration-after-statement \
	-Werror-implicit-function-declaration"
%endif

# Regenerate configure to pick up configure.in and acinclude.m4 changes.
aclocal -I m4
autoheader
automake
libtoolize
intltoolize --force
autoconf

# See Ross Burton's blog entry for why we want --with-libdb.
# http://www.burtonini.com/blog//computers/eds-libdb-2006-07-18-10-40

%configure \
	--with-libdb=/usr \
	--enable-file-locking=fcntl \
	--enable-dot-locking=no \
	--enable-gtk-doc \
	%ldap_flags %krb5_flags %nntp_flags %ssl_flags %imap4_flags \
	%keyring_flags
export tagname=CC
make %{?_smp_mflags} LIBTOOL=/usr/bin/libtool

%install
rm -rf $RPM_BUILD_ROOT
export tagname=CC
make DESTDIR=$RPM_BUILD_ROOT LIBTOOL=/usr/bin/libtool install

# remove libtool archives for importers and the like
find $RPM_BUILD_ROOT/%{_libdir} -name '*.la' -exec rm {} \;
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/evolution-data-server-%{eds_api_version}/camel-providers/*.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/evolution-data-server-%{eds_api_version}/extensions/*.a

# give the libraries some executable bits 
find $RPM_BUILD_ROOT -name '*.so.*' -exec chmod +x {} \;

%find_lang %{name}-%{eds_base_version}

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}-%{eds_base_version}.lang
%defattr(-,root,root,-)
%doc README COPYING ChangeLog NEWS AUTHORS
%{_libdir}/*.so.*
%{_libexecdir}/e-addressbook-factory
%{_libexecdir}/e-calendar-factory
%{_libexecdir}/camel-index-control-%{eds_api_version}
%{_libexecdir}/camel-lock-helper-%{eds_api_version}
%{_datadir}/evolution-data-server-%{eds_base_version}
## %{_datadir}/idl/evolution-data-server-%{eds_api_version}
%{_datadir}/pixmaps/evolution-data-server
#{_libdir}/evolution-data-server-%{eds_api_version}
%{_datadir}/dbus-1/services/*

%dir %{_libdir}/evolution-data-server-%{eds_api_version}
%dir %{camel_provider_dir}
%dir %{eds_extensions_dir}

# Camel providers:
%{camel_provider_dir}/libcamelgroupwise.so
%{camel_provider_dir}/libcamelgroupwise.urls

%{camel_provider_dir}/libcamelimap.so
%{camel_provider_dir}/libcamelimap.urls

%if %{support_imap4_provider}
%{camel_provider_dir}/libcamelimap4.so
%{camel_provider_dir}/libcamelimap4.urls
%endif

%{camel_provider_dir}/libcamellocal.so
%{camel_provider_dir}/libcamellocal.urls

%{camel_provider_dir}/libcamelnntp.so
%{camel_provider_dir}/libcamelnntp.urls

%{camel_provider_dir}/libcamelpop3.so
%{camel_provider_dir}/libcamelpop3.urls

%{camel_provider_dir}/libcamelsendmail.so
%{camel_provider_dir}/libcamelsendmail.urls

%{camel_provider_dir}/libcamelsmtp.so
%{camel_provider_dir}/libcamelsmtp.urls

%{camel_provider_dir}/libcamelimapx.so
%{camel_provider_dir}/libcamelimapx.urls

# e-d-s extensions:
%{eds_extensions_dir}/libebookbackendfile.so
%{eds_extensions_dir}/libebookbackendgoogle.so
%{eds_extensions_dir}/libebookbackendgroupwise.so
%{eds_extensions_dir}/libebookbackendldap.so
%{eds_extensions_dir}/libebookbackendvcf.so
%{eds_extensions_dir}/libebookbackendwebdav.so
%{eds_extensions_dir}/libecalbackendcontacts.so
%{eds_extensions_dir}/libecalbackendfile.so
%{eds_extensions_dir}/libecalbackendgroupwise.so
%{eds_extensions_dir}/libecalbackendhttp.so
%{eds_extensions_dir}/libecalbackendweather.so
%{eds_extensions_dir}/libecalbackendcaldav.so
## %{eds_extensions_dir}/libecalbackendgoogle.so

%files devel
%defattr(-,root,root,-)
%{_includedir}/evolution-data-server-%{eds_base_version}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%defattr(-,root,root,-)
%{_datadir}/gtk-doc/html/camel
%{_datadir}/gtk-doc/html/libebackend
%{_datadir}/gtk-doc/html/libebook
%{_datadir}/gtk-doc/html/libecal
%{_datadir}/gtk-doc/html/libedata-book
%{_datadir}/gtk-doc/html/libedata-cal
%{_datadir}/gtk-doc/html/libedataserver
%{_datadir}/gtk-doc/html/libedataserverui

%changelog
* Sat Nov 20 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.32.1-1
- new upstream release 

* Sun Oct 03 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.32.0-1
- new upstream release 
- remove Requires: gnome-vfs2, libglade2, libgnomeui
- remove BuildRequires: gnome-vfs2-devel, libglade2-devel, libgnomeui-devel
- add BuildRequires: libgdata
- add Requires: nspr-devel, nss-devel (devel package)
- drop Patch11

* Thu Sep 23 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.30.2-2
- rebuild with rpm-4.8.1 for pkg-config file

* Mon Jun 21 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.30.2-1
- new upstream release 

* Sat May 01 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.30.1-1
- new upstream release 

* Fri Apr 02 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.30.0-1
- new upstream release 
- remove BuildRequires: libbonobo-devel
- remove Requires: libbonobo
- drop Patch10
- add configure option (--with-krb5-libs, --with-krb5-includes)

* Thu Feb 11 2010 NAKAMURA Kenta <kenta@vinelinux.org> 2.28.1-2
- rebuilt with db4-4.8

* Sat Oct 31 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.28.1-1
- new upstream release 

* Sat Jul 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.26.3-1
- new upstream release

* Thu May 28 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.26.2-1
- new upstream release

* Sat Apr 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.26.1.1-1
- new upstream release

* Sat Apr  4 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.26.0-2
- added Requires: libical-devel >= 0.43 to devel package

* Sat Mar 21 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.26.0-1
- new upstream release
- add BR: libgweather-devel >= 2.26.0
- add BR: libical-devel >= 0.43

* Sat Mar  7 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.24.5-1
- new upstream release 
- added BuildRequires: sqlite3-devel

* Mon Jan 19 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.24.2-2
- enabled krb5 support

* Sun Dec 14 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.24.2-1
- new upstream release

* Wed Oct 22 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.24.1-1
- new upstream release

* Wed Sep 24 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.24.0-1
- new upstream release

* Mon Jun 30 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.3-1
- new upstream release

* Fri Jun 20 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.2-2
- rebuilt with db4-4.6.21

* Sat May 31 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.2-1
- new upstream release

* Sun May  4 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.1.1-1vl5
- new upstream release

* Wed Apr  9 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.1-1vl5
- new upstream release

* Mon Mar 31 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.22.0-1vl5
- new upstream release based on Fedora package 2.20.0-3.fc9
  * Mon Mar 24 2008 Matthew Barnes <mbarnes@redhat.com> - 2.22.0-3.fc9
  - Add patch for GNOME bug #523023 (EFolder leak in evo-ex-storage).
  * Tue Mar 11 2008 Matthew Barnes <mbarnes@redhat.com> - 2.22.0-2.fc9
  - Add patch for RH bug #296671 (GC servers may not support NTLM).
  * Thu Feb 14 2008 Matthew Barnes <mbarnes@redhat.com> - 2.21.91-3.fc9
  - Try removing the ancient "ldap-x86_64-hack" patch.
  * Mon Feb 11 2008 Matthew Barnes <mbarnes@redhat.com> - 2.21.91-1.fc9
  - Add patch for GNOME bug #516074 (latest glibc breaks Camel).
- split doc subpackage

* Sat Jul 28 2007 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.10.1-1vl2
- fixed dependancy

* Sat Jul 14 2007 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.10.1-1vl1
- updated to 1.10.3.1 based on Fedora package 1.10.1-1.fc7
  * Wed Apr 04 2007 Matthew Barnes <mbarnes@redhat.com> - 1.10.0-6.fc7
  - Revise patch for GNOME bug #417999 (another ESourceComboBox goof).
  * Mon Apr 02 2007 Matthew Barnes <mbarnes@redhat.com> - 1.10.0-5.fc7
  - Make the new ESourceComboBox widget work properly (RH bug #234760).
  * Tue Mar 27 2007 Matthew Barnes <mbarnes@redhat.com> - 1.10.0-4.fc7
  - Link to static evolution-openldap library (RH bug #210126).
  - Require openssl-devel when statically linking against openldap.
  - Add -Wdeclaration-after-statement to strict build settings.
  * Wed Mar 14 2007 Matthew Barnes <mbarnes@redhat.com> - 1.10.0-2.fc7
  - Modify patch for GNOME bug #376991 to fix RH bug #231994.
  - Add patch for GNOME bug #417999 (avoid deprecated GTK+ symbols).
  * Mon Mar 12 2007 Matthew Barnes <mbarnes@redhat.com> - 1.10.0-1.fc7
  - Update to 1.10.0
  * Fri Mar 09 2007 Matthew Barnes <mbarnes@redhat.com> - 1.9.92-4.fc7
  - Add patch for GNOME bug #415922 (support MS ISA Server 2004).
  - Patch by Kenny Root.
- rebuilt with nss-devel and nspr-devel

* Fri May 11 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.8.2-0vl2
- rebuilt with new toolchain and db4-4.3.x

* Sun Nov 26 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.8.2-0vl1
- new upstream release

* Sat Nov 11 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.8.1-0vl1
- new upstream release
- dropped Patch16, 17, 19, 20 and 21 (merged into upstream)

* Sat Oct  7 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.8.0-11vl1
- new upstream release
- rebuilt with openssl instead of mozilla-nss

* Mon Aug 28 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.4.2.1-0vl2
- rebuilt with openldap-2.3.24-0vl4

* Thu Dec  1 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.4.2.1-0vl1
- new upstream release
- build with libsoap-2.2.7

* Tue Nov  8 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.4.1.1-0vl1
- new upstream release

* Sun Sep 25 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.4.0-2vl1
- new upstream release
- added/removed Patches based on Fedora packages
  * Tue Aug 23 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.8-3
  - Updated patch 102 to fix further implicit function declarations
  * Mon Jul 25 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.5-2
  - Added patch to use nspr rather than mozilla-nspr when doing pkg-config 
    tests (Patch5: evolution-data-server-1.3.5-nspr_fix.patch)
  * Mon Jul 25 2005 David Malcolm <dmalcolm@redhat.com> - 1.3.5-1
  - Removed upstreamed patch: 
    evolution-data-server-1.2.0-cope-with-a-macro-called-read.patch
  * Mon Apr 11 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.2-2
  - added patch to calendar/libecal/e-cal.c to fix missing declaration 
    of open_calendar
- rebuilt with mozilla-1.7.12

* Thu May 04 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.2.1-0vl2
- rebuilt with mozilla-1.7.7

* Tue Apr 12 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.1-0vl1
- initial build for Vine Linux based on FC package
- disable krb5 support

* Thu Mar 17 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.1-1
- 1.2.1

* Thu Mar 10 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-3
- Removed explicit run-time spec-file requirement on mozilla.
  The Mozilla NSS API/ABI stabilised by version 1.7.3
  The libraries are always located in the libdir
  However, the headers are in /usr/include/mozilla-%{mozilla_build_version}
  and so they move each time the mozilla version changes.
  So we no longer have an explicit mozilla run-time requirement in the specfile; 
  a requirement on the appropriate NSS and NSPR .so files is automagically generated on build.
  We have an explicit, exact build-time version, so that we can find the headers (without
  invoking an RPM query from the spec file; to do so is considered bad practice)
- Introduced mozilla_build_version, to replace mozilla_version
- Set mozilla_build_version to 1.7.6 to reflect current state of tree

* Tue Mar  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-2
- Added a patch to deal with glibc defining a macro called "read"

* Tue Mar  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.2.0-1
- 1.2.0
- Removed patch for GCC 4 as this is now in upstream tarball

* Wed Mar  2 2005 Jeremy Katz <katzj@redhat.com> - 1.1.6-6
- rebuild to fix library linking silliness

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-5
- disabling gtk-doc on ia64 and s390x

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-4
- added macro use_gtk_doc; added missing BuildRequires on gtk-doc; enabled gtk-doc generation on all platforms (had been disabled on ia64)

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-3
- extended patch to deal with camel-groupwise-store-summary.c

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-2
- added patch to fix badly-scoped declaration of "namespace_clear" in camel-imap-store-summary.c

* Tue Mar  1 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.6-1
- 1.1.6

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-3
- rebuild

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-2
- forgot to fix sources

* Tue Feb  8 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.5-1
- 1.1.5

* Thu Jan 27 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.2-1
- Update from unstable 1.1.4.1 to unstable 1.1.1.4.2

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-3
- disable gtk-doc generation on ia64 for now

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-2
- Exclude ppc64 due to missing mozilla dependency

* Wed Jan 26 2005 David Malcolm <dmalcolm@redhat.com> - 1.1.4.1-1
- Update from 1.0.3 to 1.1.4.1
- Updated eds_major from 1.0 to 1.2; fixed translation search path.
- Removed 64-bit patch for calendar backend hash table; upstream now stores pointers to ECalBackendFactory, rather than GType
- Removed calendar optimisation patch for part of part of bug #141283 as this is now in the upstream tarball
- Added /usr/lib/evolution-data-server-%{eds_major} to cover the extensions, plus the camel code now in e-d-s, rather than evolution
- Added /usr/share/pixmaps/evolution-data-server-%{eds_major} to cover the category pixmaps
- Camel code from evolution is now in evolution-data-server:
  - Added camel-index-control and camel-lock-helper to packaged files
  - Added mozilla dependency code from the evolution package
  - Ditto for LDAP
  - Ditto for krb5
  - Ditto for NNTP support handling
  - Ditto for --enable-file-locking and --enable-dot-locking
- Added requirements on libbonobo, libgnomeui, gnome-vfs2, GConf2, libglade2
- Updated libsoup requirement from 2.2.1 to 2.2.2
- Enabled gtk-doc

* Wed Dec 15 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.3-2
- fixed packaging of translation files to reflect upstream change to GETTEXT_PACKAGE being evolution-data-server-1.0 rather than -1.5

* Wed Dec 15 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.3-1
- update from upstream 1.0.2 to 1.0.3:
  * Address Book
    - prevent e_book_commit_contact from crashing on multiple calls (Diego Gonzalez)
    - prevent file backend from crashing if uid of vcard is NULL (Diego Gonzalez)

  * Calendar
    #XB59904 - Speed up calendar queries (Rodrigo)
    #XB69624 - make changes in evo corresponding to soap schema changes  (Siva)
    - fix libical build for automake 1.9 (Rodney)
    - fix putenv usage for portability (Julio M. Merino Vidal)

  * Updated Translations:
    - sv (Christian Rose)

- Removed patches to fix build on x86_64 and calendar optimisation for XB59004 as these are in the upstream tarball

* Tue Dec  7 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-6
- Amortize writes to a local cache of a webcal calendar, fixing further aspect of #141283 (upstream bugzilla #70267), as posted to mailing list here:
http://lists.ximian.com/archives/public/evolution-patches/2004-December/008338.html
(The groupwise part of that patch did not cleanly apply, so I removed it).

* Thu Dec  2 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-5
- Added fix for #141283 (upstream bugzilla XB 59904), a backported calendar 
optimisation patch posted to upstream development mailing list here:
http://lists.ximian.com/archives/public/evolution-patches/2004-November/008139.html

* Wed Nov  3 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-4
- Added patch to fix usage of GINT_TO_POINTER/GPOINTER_TO_INT for calendar backend GType hash table, breaking on ia64  (#136914)

* Wed Oct 20 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-3
- added workaround for a backend leak that causes the "contacts" calendar 
backend to hold open an EBook for the local contacts (filed upstream at:
http://bugzilla.ximian.com/show_bug.cgi?id=68533 ); this was causing e-d-s to
never lose its last addressbook, and hence never quit.  We workaround this by
detecting this condition and exiting when it occurs, fixing bug #134851 and #134849.

* Tue Oct 12 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-2
- added patch to fix build on x86_64 (had multiple definitions of mutex code in libdb/dbinc.mutex.h)

* Tue Oct 12 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.2-1
- update from 1.0.1 to 1.0.2
- increased libsoup requirement to 2.2.1 to match configuration script

* Tue Sep 28 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.1-1
- update from 1.0.0 to 1.0.1
- removed patch that fixed warnings in calendar code (now in upstream tarball)

* Mon Sep 20 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.0-2
- fixed various warnings in the calendar code 
  (filed upstream here: http://bugzilla.ximian.com/show_bug.cgi?id=66383)

* Tue Sep 14 2004 David Malcolm <dmalcolm@redhat.com> - 1.0.0-1
- update from 0.0.99 to 1.0.0
- changed path in FTP source location from 0.0 to 1.0

* Tue Aug 31 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.99-1
- update from 0.0.98 to 0.0.99
- increased libsoup requirement to 2.2.0 to match configuration script

* Mon Aug 16 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.98-1
- updated tarball from 0.0.97 to 0.0.98; updated required libsoup version to 2.1.13

* Thu Aug  5 2004 Warren Togami <wtogami@redhat.com> - 0.0.97-2
- pkgconfig -devel Requires libbonobo-devel, libgnome-devel

* Wed Aug  4 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.97-1
- upgraded to 0.0.97; rewrote the package's description

* Mon Jul 26 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Tue Jul 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.96-2
- added version numbers to the BuildRequires test for libsoup-devel and ORBit2-devel

* Tue Jul 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.96-1
- 0.0.96; libsoup required is now 2.1.12

* Thu Jul  8 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Wed Jul  7 2004 David Malcolm <dmalcolm@redhat.com>
- rebuilt

* Tue Jul  6 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.95-1
- 0.0.95

* Thu Jun 17 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94.1-1
- 0.0.94.1

* Mon Jun  7 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94-2
- rebuilt

* Mon Jun  7 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.94-1
- 0.0.94

* Wed May 26 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-4
- added ORBit2 requirement

* Fri May 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-3
- rebuild again

* Fri May 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-2
- rebuilt

* Thu May 20 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.93-1
- 0.0.93; libsoup required is now 2.1.10

* Wed Apr 21 2004 David Malcolm <dmalcolm@redhat.com> - 0.0.92-1
- Update to 0.0.92; added a define and a requirement on the libsoup version

* Wed Mar 10 2004 Jeremy Katz <katzj@redhat.com> - 0.0.90-1
- 0.0.90

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Jan 26 2004 Jeremy Katz <katzj@redhat.com> - 0.0.6-1
- 0.0.6

* Wed Jan 21 2004 Jeremy Katz <katzj@redhat.com> - 0.0.5-2
- better fix by using system libtool

* Mon Jan 19 2004 Jeremy Katz <katzj@redhat.com> 0.0.5-1
- add some libdb linkage to make the build on x86_64 happy

* Wed Jan 14 2004 Jeremy Katz <katzj@redhat.com> 0.0.5-0
- update to 0.0.5

* Sat Jan  3 2004 Jeremy Katz <katzj@redhat.com> 0.0.4-0
- Initial build.
