Summary: A GNU file archiving program.
Summary(ja): GNU ファイルアーカイブプログラム
Name: tar
Version: 1.25
Release: 1%{?_dist_release}
License: GPLv3+
Group: Applications/Archiving
Source: ftp://ftp.gnu.org/pub/gnu/tar/tar-%{version}.tar.bz2
Patch0: tar-1.13.18-manpage.patch
Patch8: tar-1.20-loneZeroWarning.patch
Patch10: tar-1.15.1-gcc4.patch

#Fix extracting sparse files to a filesystem like vfat,
#when ftruncate may fail to grow the size of a file.(#179507)
Patch11: tar-1.15.1-vfatTruncate.patch
#change inclusion defaults of tar to "--wildcards --anchored
#--wildcards-match-slash" for compatibility reasons (#206841)
Patch12: tar-1.17-wildcards.patch
#oldarchive option was not working(#594044)
Patch13: tar-1.23-oldarchive.patch

# adhoc but useful patch for z option accepts bzip2ed tarball.
Patch100: tar-1.13.6-barterly.patch
Patch110: tar-1.22-rtapelib-overflow.patch

BuildRequires: autoconf texinfo

Requires(post,postun): install-info
Buildroot: %{_tmppath}/%{name}-%{version}-root


%description
The GNU tar program saves many files together in one archive and can
restore individual files (or all of the files) from that archive. Tar
can also be used to add supplemental files to an archive and to update
or list files in the archive. Tar includes multivolume support,
automatic archive compression/decompression, the ability to perform
remote archives, and the ability to perform incremental and full
backups.

If you want to use tar for remote backups, you also need to install
the rmt package.


%description -l ja
GNU tar プログラムは多くのファイルを一つのファイルにまとめたりアーカイブ
から個々のファイルを(または全てのファイルを)リストアしたりする。tar はまた
追加ファイルを加えたりアーカイブファイル中のリストを更新したりするために
使われる。

tar はマルチボリュームサポート、自動アーカイブ圧縮/伸長、リモート
アーカイブの取り扱う機能、そして差分バックアップとフルバックアップをする
機能を含んでいる。

もしリモートバックアップのために tar をインストールするなら、rmt パッケージ
もまたインストールする必要がある。


%prep
%setup -q
%patch0 -p1 -b .manpage
%patch8 -p1 -b .loneZeroWarning
%patch11 -p1 -b .vfatTruncate
%patch12 -p1 -b .wildcards
%patch13 -p1 -b .oldarchive

%patch100 -p1 -b .accept-bz2
%patch110 -p1 -b .CVE-2010-0624

%build
autoreconf
%configure --bindir=/bin --libexecdir=/sbin
make LIBS=-lbsd %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

make prefix=${RPM_BUILD_ROOT}%{_prefix} \
    localedir=${RPM_BUILD_ROOT}%{_prefix}/share/locale \
    bindir=${RPM_BUILD_ROOT}/bin \
    libexecdir=${RPM_BUILD_ROOT}/sbin \
    mandir=${RPM_BUILD_ROOT}%{_mandir} \
    infodir=${RPM_BUILD_ROOT}%{_infodir} \
	install
ln -s tar ${RPM_BUILD_ROOT}/bin/gtar

( cd $RPM_BUILD_ROOT
  for dir in ./bin ./sbin .%{_prefix}/bin .%{_prefix}/libexec
  do
    [ -d $dir ] || continue
    strip $dir/* || :
  done
  gzip -9nf .%{_infodir}/tar.info*
  rm -f .%{_infodir}/dir
)

mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/man1
install -c -m644 tar.1 ${RPM_BUILD_ROOT}%{_mandir}/man1

rm -f ${RPM_BUILD_ROOT}/sbin/rmt

%find_lang %name


%post
/sbin/install-info %{_infodir}/tar.info.gz %{_infodir}/dir


%preun
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/tar.info.gz %{_infodir}/dir
fi


%clean
rm -rf ${RPM_BUILD_ROOT}


%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog* NEWS README THANKS TODO
/bin/tar
/bin/gtar
%{_mandir}/man1/tar.1*
%{_infodir}/tar.info*


%changelog
* Mon Nov 8 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 1.25-1
- new upstream release
- changed source archive type (gzip to bzip2)
- modified Patch8 a little
- added Patch11,12,13 from Fedora development
- added BuildRequires: autoconf texinfo
- run autoreconf on %%build

* Tue Mar 16 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> - 1.22-4
- add patch110 for fix CVE-2010-0624 (rmt) from fc11

* Thu Apr 30 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 1.22-3
- add missing documents

* Mon Apr 13 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.22-2
- spec in utf-8

* Mon Mar 16 2009 Toshiharu Kudoh <toshi.kd2@gmail.com> 1.22-1
- new upstream release
- improved tar-1.20-loneZeroWarning.patch (refer to Fedora package)

* Thu Apr 24 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.20-1
- new upstream release
- remove unneeded patches

* Mon Dec 25 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.15.1-0vl3
- rebuilt for VineSeed

* Thu Nov 30 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.15.1-0vl2.1
- add patch120 for fix CVE-2006-6097

* Sun Sep 17 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.15.1-0vl2
- add patch110 for fix CVE-2006-0300

* Mon May 02 2005 Satoshi MACHINO <machino@vinelinux.org> 1.15.1-0vl1
- new upstream release
- fixed patch6 and patch7 for new upstream release
- some patches are imported from fedora package. and fixed
	-- stop issuing lone zero block warnings(patch8)
	-- fixed testsuite(patch9)
	-- don't applyed(patch10)
	-- fixed offset had incorrect type(patch11)

* Sun Jun 13 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 1.14-0vl1
- new upstream release
- some patches are imported from fedora package.

* Fri May  2 2003 IWAI Masaharu <iwai@alib.jp> 1.3.25-8vl4
- rebuild with new toolchain
  - update BuildRequire (autoconf253 -> autoconf)

* Thu Oct 31 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 1.3.25-8vl3
- add adhoc but useful patch100 for "z" option to accepts bz2 tarball.

* Wed Oct 30 2002 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.3.25-8vl2
- Oops the spec was in Shift-JIS. Fixed.

* Wed Oct 30 2002 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.3.25-8vl1
- based on 1.3.25-8 from Rawhide and built for Vine Linux
- the previous Vine package was 1.3.18-0vl2. Vine's changelog was as follows:

  - Wed Feb 20 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 1.13.18-0vl2
  - rebuild to remove rpmlib dependancy

  - Sat May 26 2001 <sagami@vinelinux.org>
  - 1.13.18-0vl1: based on 1.13.18-1 and added Japanese summary and description
  - added barterly patch

* Fri Aug 23 2002 Phil Knirsch <pknirsch@redhat.com> 1.13.25-8
- Included security patch from errata release.

* Mon Jul  1 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.25-7
- Fix argv NULL termination (#64869)

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Apr  9 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.25-4
- Fix build with autoconf253 (LIBOBJ change; autoconf252 worked)

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Oct 23 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.25-2
- Don't include hardlinks to sockets in a tar file (#54827)

* Thu Sep 27 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.25-1
- 1.13.25

* Tue Sep 18 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.22-1
- Update to 1.13.22, adapt patches

* Mon Aug 27 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.19-6
- Fix #52084

* Thu May 17 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.13.19-5
- Fix build with current autoconf (stricter checking on AC_DEFINE)
- Fix segfault when tarring directories without having read permissions
  (#40802)

* Tue Mar  6 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Don't depend on librt.

* Fri Feb 23 2001 Trond Eivind Glomsr <teg@redhat.com>
- langify

* Thu Feb 22 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up the man page (#28915)

* Wed Feb 21 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 1.3.19, nukes -I and fixes up -N
- Add -I back in as an alias to -j with a nice loud warning

* Mon Oct 30 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 1.3.18
- Update man page to reflect changes

* Thu Oct  5 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix the "ignore failed read" option (Bug #8330)

* Mon Sep 25 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- fix hang on tar tvzf - <something.tar.gz, introduced by
  exit code fix (Bug #15448), Patch from Tim Waugh <twaugh@redhat.com>

* Fri Aug 18 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- really fix exit code (Bug #15448)

* Mon Aug  7 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- fix exit code (Bug #15448), patch from Tim Waugh <twaugh@redhat.com>

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Mon Jun 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- FHSify

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- fix for ia64

* Wed Feb  9 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- Fix the exclude bug (#9201)

* Wed Feb 02 2000 Cristian Gafton <gafton@redhat.com>
- man pages are compressed
- fix description
- fix fnmatch build problems

* Sun Jan  9 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- 1.13.17
- remove dotbug patch (fixed in base)
- update download URL

* Fri Jan  7 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- Fix a severe bug (tar xf any_package_containing_. would delete the
  current directory)

* Wed Jan  5 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- 1.3.16
- unset LINGUAS before running configure

* Tue Nov  9 1999 Bernhard Rosenkr舅zer <bero@redhat.com>
- 1.13.14
- Update man page to know about -I / --bzip
- Remove dependancy on rmt - tar can be used for anything local
  without it.

* Fri Aug 27 1999 Preston Brown <pbrown@redhat.com>
- upgrade to 1.13.11.

* Wed Aug 18 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.13.9.

* Thu Aug 12 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.13.6.
- support -y --bzip2 options for bzip2 compression (#2415).

* Fri Jul 23 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.13.5.

* Tue Jul 13 1999 Bill Nottingham <notting@redhat.com>
- update to 1.13

* Sat Jun 26 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.12.64014.
- pipe patch corrected for remote tars now merged in.

* Sun Jun 20 1999 Jeff Johnson <jbj@redhat.com>
- update to tar-1.12.64013.
- subtract (and reopen #2415) bzip2 support using -y.
- move gtar to /bin.

* Tue Jun 15 1999 Jeff Johnson <jbj@redhat.com>
- upgrade to tar-1.12.64011 to
-   add bzip2 support (#2415)
-   fix filename bug (#3479)

* Mon Mar 29 1999 Jeff Johnson <jbj@redhat.com>
- fix suspended tar with compression over pipe produces error (#390).

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 8)

* Mon Mar 08 1999 Michael Maher <mike@redhat.com>
- added patch for bad name cache. 
- FIXES BUG 320

* Wed Feb 24 1999 Preston Brown <pbrown@redhat.com>
- Injected new description and group.

* Fri Dec 18 1998 Preston Brown <pbrown@redhat.com>
- bumped spec number for initial rh 6.0 build

* Tue Aug  4 1998 Jeff Johnson <jbj@redhat.com>
- add /usr/bin/gtar symlink (change #421)

* Tue Jul 14 1998 Jeff Johnson <jbj@redhat.com>
- Fiddle bindir/libexecdir to get RH install correct.
- Don't include /sbin/rmt -- use the rmt from dump.
- Turn on nls.

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Oct 16 1997 Donnie Barnes <djb@redhat.com>
- updated from 1.11.8 to 1.12
- various spec file cleanups
- /sbin/install-info support

* Thu Jun 19 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Thu May 29 1997 Michael Fulbright <msf@redhat.com>
- Fixed to include rmt
